==> eccodeslib-2.40.0-cp313-cp313-macosx_13_0_arm64.whl: eccodeslib/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.8.4"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.8.4"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/opt/homebrew/share/ecbuild/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Darwin-22.5.0"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "macosx.64"
#define ECCODES_OS_VERSION       "22.5.0"
#define ECCODES_SYS_PROCESSOR    "arm64"

#define ECCODES_BUILD_TIMESTAMP  "20250210123336"
#define ECCODES_BUILD_TYPE       "RelWithDebInfo"

#define ECCODES_C_COMPILER_ID      "AppleClang"
#define ECCODES_C_COMPILER_VERSION "14.0.3.14030022"

#define ECCODES_CXX_COMPILER_ID      "AppleClang"
#define ECCODES_CXX_COMPILER_VERSION "14.0.3.14030022"

#define ECCODES_C_COMPILER       "/Library/Developer/CommandLineTools/usr/bin/cc"
#define ECCODES_C_FLAGS          " -pipe -O2 -g -DNDEBUG"

#define ECCODES_CXX_COMPILER     "/Library/Developer/CommandLineTools/usr/bin/c++"
#define ECCODES_CXX_FLAGS        " -pipe -O2 -g -DNDEBUG"

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/tmp/eccodes/target/eccodes"
#define ECCODES_INSTALL_BIN_DIR   "/tmp/eccodes/target/eccodes/bin"
#define ECCODES_INSTALL_LIB_DIR   "/tmp/eccodes/target/eccodes/lib"
#define ECCODES_INSTALL_DATA_DIR  "/tmp/eccodes/target/eccodes/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/opt/actions-runner/work/_work/eccodes/eccodes/proj"
#define ECCODES_DEVELOPER_BIN_DIR "/tmp/eccodes/build"

/* Fortran support */

#if 0

#define ECCODES_Fortran_COMPILER_ID      ""
#define ECCODES_Fortran_COMPILER_VERSION ""

#define ECCODES_Fortran_COMPILER ""
#define ECCODES_Fortran_FLAGS    ""

#endif

#endif /* ECCODES_ecbuild_config_h */

==> eccodeslib-2.41.dev0-1-cp313-cp313-macosx_13_0_arm64.whl: eccodeslib/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.9.1"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.9.1"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/opt/actions-runner/work/_work/eccodes/eccodes/ecbuild/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Darwin-22.5.0"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "macosx.64"
#define ECCODES_OS_VERSION       "22.5.0"
#define ECCODES_SYS_PROCESSOR    "arm64"

#define ECCODES_BUILD_TIMESTAMP  "20250305100227"
#define ECCODES_BUILD_TYPE       "RelWithDebInfo"

#define ECCODES_C_COMPILER_ID      "AppleClang"
#define ECCODES_C_COMPILER_VERSION "14.0.3.14030022"

#define ECCODES_CXX_COMPILER_ID      "AppleClang"
#define ECCODES_CXX_COMPILER_VERSION "14.0.3.14030022"

#define ECCODES_C_COMPILER       "/Library/Developer/CommandLineTools/usr/bin/cc"
#define ECCODES_C_FLAGS          " -pipe -O2 -g -DNDEBUG"

#define ECCODES_CXX_COMPILER     "/Library/Developer/CommandLineTools/usr/bin/c++"
#define ECCODES_CXX_FLAGS        " -pipe -O2 -g -DNDEBUG"

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/tmp/eccodes/target/eccodes"
#define ECCODES_INSTALL_BIN_DIR   "/tmp/eccodes/target/eccodes/bin"
#define ECCODES_INSTALL_LIB_DIR   "/tmp/eccodes/target/eccodes/lib"
#define ECCODES_INSTALL_DATA_DIR  "/tmp/eccodes/target/eccodes/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/opt/actions-runner/work/_work/eccodes/eccodes/proj"
#define ECCODES_DEVELOPER_BIN_DIR "/tmp/eccodes/build"

/* Fortran support */

#if 0

#define ECCODES_Fortran_COMPILER_ID      ""
#define ECCODES_Fortran_COMPILER_VERSION ""

#define ECCODES_Fortran_COMPILER ""
#define ECCODES_Fortran_FLAGS    ""

#endif

#endif /* ECCODES_ecbuild_config_h */
